@@ -1,7 +1,9 @@
+from functools import partial
 from importlib import import_module
 import inspect
 from flask.ext.restful import Api, abort
 import six
+from flask_presst.schema import Schema
 from flask_presst.resources import PresstResource, ModelResource
 from flask_presst.utils.routes import route_from
 
@@ -12,6 +14,7 @@ class PresstApi(Api):
         self._presst_resources = {}
         self._presst_resource_insts = {}
         self._model_resource_map = {}
+        self.has_schema = False
 
     def _init_app(self, app):
         super(PresstApi, self)._init_app(app)
@@ -78,6 +81,14 @@ class PresstApi(Api):
         except KeyError:
             return None
 
+    def enable_schema(self):
+        if not self.has_schema:
+            self.has_schema = True
+            self.app.add_url_rule(self._complete_url('/', ''),
+                                  view_func=self.output(Schema.as_view('schema', self)),
+                                  endpoint='schema',
+                                  methods=['GET'])
+
     def add_resource(self, resource, *urls, **kwargs):
 
         # fallback to Flask-RESTful `add_resource` implementation with regular resources:
@@ -97,48 +108,30 @@ class PresstApi(Api):
         urls = [
             '/{0}'.format(resource_name),
             '/{0}/<{1}:id>'.format(resource_name, pk_converter),
-            '/{0}/<{1}:id>/<string:route>'.format(resource_name, pk_converter),
-            '/{0}/<string:route>'.format(resource_name)
-            # FIXME does not allow for collection-wide resource methods in resources with string keys.
         ]
 
         self._presst_resources[resource_name] = resource
 
         if issubclass(resource, ModelResource):
             self._model_resource_map[resource.get_model()] = resource
-        # # add records for 2-level resource methods.
-        # for route, nested_type in six.iteritems(resource.nested_types):
-        #     #print nested_resource, route
-        #     #print '/{0}/<{1}:parent_id>/{2}'.format(resource_name, pk_converter, route)
-        #
-        #     for relationship, method in nested_type.bound_resource.nested_types.iteritems():
-        #         if not method.collection:  # 2-level nesting is only supported for collection methods.
-        #             continue
-        #
-        #         # print '/{0}/<{1}:parent_id>/{2}/{3}'.format(resource_name, pk_converter, route, relationship)
-        #
-        #     # TODO get all (nested collections) and collection resource methods from resource.
-        #     # TODO deal with recursive nested resources
-        #
-        #
-        #     # if nested_type.collection:
-        #     #     raise NotImplementedError()
-        #     # else:
-        #     #     print  '/{0}/<{1}:parent_id>/{2}'.format(resource_name, pk_converter, route)
-        #         # print 'methods:', nested_type.methods
-        #         # super(PresstApi, self).add_resource(
-        #         #     nested_type,
-        #         #     '/{0}/<{1}:parent_id>/{2}'.format(resource_name, pk_converter, route),
-        #         #     endpoint='{0}_{1}'.format(resource_name, route))
-        #
-        #
-        #     #
-        #     #print (nested_resource, nested_resource_uri)
-        #     #
-        #     #super(ModelApi, self).add_resource(nested_resource, nested_resource_uri)
-        #
-        # # Add resource with provided URL and args:
 
+        for name, child in six.iteritems(resource.nested_types):
+
+            if child.collection:
+                url = '/{0}/{1}'.format(resource_name, name)
+            else:
+                url = '/{0}/<{1}:parent_id>/{2}'.format(resource_name, pk_converter, name)
+
+            child_endpoint = '{0}_{1}'.format(resource_name, name)
+            child_view_func = self.output(child.view_factory(child_endpoint, resource))
+
+            # FIXME routing for blueprints; also needs tests
+            rule = self._complete_url(url, '')
+
+            self.app.add_url_rule(rule,
+                                  view_func=child_view_func,
+                                  endpoint=child_endpoint,
+                                  methods=child.methods, **kwargs)
 
         super(PresstApi, self).add_resource(resource, *urls, endpoint=resource_name, **kwargs)
 
